@@ -53,12 +53,14 @@ use Net::Silk qw( :basic );
 use Scalar::Util qw( refaddr );
 
 use overload (
-  '""' => \&as_str,
-  '<>' => \&_fh_iter,
-  'eq' => \&_eq,
-  '==' => \&_eq,
-  'ne' => \&_ne,
-  '!=' => \&_ne,
+  '""'  => \&as_str,
+  '<>'  => \&_fh_iter,
+  'eq'  => \&_eq,
+  '=='  => \&_eq,
+  'ne'  => \&_ne,
+  '!='  => \&_ne,
+  '<=>' => \&_cmp,
+  'cmp' => \&_cmp,
 );
 
 my %Attr;
@@ -150,6 +152,51 @@ sub as_range {
 
 sub as_str { join('/', @{shift()}) }
 
+sub _iter_ranges {
+  my $class = shift;
+  my $cidr_iter = shift;
+  my($current, $tmp);
+  my $range_iter = sub {
+    while (my $cidr = $cidr_iter->()) {
+      if (!$current) {
+        $current = $cidr->as_range;
+        next;
+      }
+      else {
+        my $first = $cidr->[0];
+        if ($first - $current->[1] == 1) {
+          $current->[1] = $cidr->last;
+          next;
+        }
+        else {
+          $tmp = $current;
+          $current = $cidr->as_range;
+          return $tmp;
+        }
+      }
+    }
+    if ($current) {
+      $tmp = $current;
+      $current = undef;
+      return $tmp;
+    }
+  };
+  sub {
+    if (wantarray) {
+      my @ranges;
+      while (my $r = $range_iter->()) {
+        push(@ranges, $r);
+      }
+      return @ranges;
+    }
+    else {
+      while (my $r = $range_iter->()) {
+        return $r;
+      }
+    }
+  };
+}
+
 sub _eq {
   my($self, $other) = @_;
   $other = (ref $self)->new($other) unless UNIVERSAL::isa($other, ref $self);
@@ -162,6 +209,12 @@ sub _ne {
   $self->ip != $other->ip || $self->prefix != $other->prefix;
 }
 
+sub _cmp {
+  my($self, $other) = @_;
+  $other = (ref $self)->new($other) unless UNIVERSAL::isa($other, ref $self);
+  ($self->ip <=> $other->ip) || ($self->prefix <=> $other->prefix);
+}
+
 sub DESTROY {
   delete $Attr{refaddr(shift)};
 }
@@ -205,8 +258,8 @@ Net::Silk::CIDR - SiLK IP CIDR class
 =head1 DESCRIPTION
 
 C<Net::Silk::CIDR> is a lightweight wrapper around a CIDR block
-specified by an IP and prefix bits. It is returned by iterators
-in L<Net::Silk::IPSet> and L<Net::Silk::Pmap>.
+specified by an IP and prefix bits. It is returned by iterators in
+L<Net::Silk::IPSet>, L<Net::Silk::Pmap>, and L<Net::Silk::IPWildcard>.
 
 =head1 METHODS
 
@@ -271,6 +324,7 @@ The following operators are overloaded:
   <>     ""
   eq     ==
   ne     !=
+  cmp    <=>
 
 =head1 SEE ALSO
 
