@@ -345,11 +345,10 @@ with the C<E<lt>E<gt>> operator. The following are equivalent:
 
 =head1 SEE ALSO
 
-L<Net::Silk::RWRec>, L<Net::Silk::IPSet>, L<Net::Silk::IPWildcard>, L<Net::Silk::Bag>, L<Net::Silk::Pmap>, L<Net::Silk::Site>, L<silk(7)>
-
+L<Net::Silk>, L<Net::Silk::RWRec>, L<Net::Silk::IPSet>, L<Net::Silk::Bag>, L<Net::Silk::Pmap>, L<Net::Silk::IPWildcard>, L<Net::Silk::Range>, L<Net::Silk::CIDR>, L<Net::Silk::IPAddr>, L<Net::Silk::TCPFlags>, L<Net::Silk::ProtoPort>, L<Net::Silk::Site>, L<silk(7)>
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2011-2015 by Carnegie Mellon University
+Copyright (C) 2011-2016 by Carnegie Mellon University
 
 Use of the Net-Silk library and related source code is subject to the
 terms of the following licenses:
