@@ -383,43 +383,7 @@ sub iter_cidr {
 
 sub iter_ranges {
   my $self = shift;
-  my $iter = $self->iter_cidr;
-  my($current, $tmp);
-  my $range_iter = sub {
-    while (my $cidr = $iter->()) {
-      if (!$current) {
-        $current = $cidr->as_range;
-        next;
-      }
-      else {
-        my $first = $cidr->[0];
-        if ($first - $current->[1] == 1) {
-          $current->[1] = $cidr->last;
-          next;
-        }
-        else {
-          $tmp = $current;
-          $current = $cidr->as_range;
-          return $tmp;
-        }
-      }
-    }
-    return $current if $current;
-  };
-  sub {
-    if (wantarray) {
-      my @ranges;
-      while (my $r = $range_iter->()) {
-        push(@ranges, $r);
-      }
-      return @ranges;
-    }
-    else {
-      while (my $r = $range_iter->()) {
-        return $r;
-      }
-    }
-  };
+  SILK_CIDR_CLASS->_iter_ranges($self->iter_cidr);
 }
 
 sub iter_bag {
@@ -855,21 +819,6 @@ Remove all items in the provided list of I<items> from this set.
 
 Specifically remove an IP address (string or object) from this set.
 
-=item remove_cidr($ip, $prefix)
-
-=item remove_cidr($cidr)
-
-Specifically remove a CIDR block from this set. A single argument can be
-provided as a string representation of the CIDR block (x.x.x.x/n).
-
-=item remove_range($low, $high)
-
-=item remove_range($range)
-
-Specifically remove the given range of IP addresses (string or object)
-from this set, inclusive. A single argument can be provided as a string
-representation of a range (x.x.x.x-y.y.y.y).
-
 =item remove_wildcard($wc)
 
 Specifically remove an IPWildcard (string or object) from this set.
