@@ -101,10 +101,7 @@ sub new {
     $parms{$p} = $Defaults{$p} unless defined $parms{$p};
   }
   $self->_set_content_type($parms{type});
-  if (defined $parms{default}) {
-    my $val = $self->_get_or_insert_label($parms{default});
-    $self->_set_default_value($val);
-  }
+  $self->_set_default($parms{default}) if defined $parms{default};
   $self->_set_name($parms{name}) if defined $parms{name};
   my $type = $self->_get_content_type;
   if ($type == SILK_PMAP_TYPE_IPV4) {
@@ -119,7 +116,7 @@ sub new {
   else {
     die "unknown pmap content type: $type";
   }
-  $Attr{$self}->[MAX_LABEL_SIZE] = 0;
+  $Attr{$self}->[MAX_LABEL_SIZE] = length($parms{default} || "UNKNOWN");
   $self;
 }
 
@@ -170,6 +167,8 @@ sub _set_default {
   my $self  = shift;
   my $label = shift || croak "label required";
   my $attr = $Attr{$self} ||= [];
+  $attr->[MAX_LABEL_SIZE] = length($label)
+      if length($label) > ($attr->[MAX_LABEL_SIZE] || 0);
   my $val = $self->_get_or_insert_label($label);
   $self->_set_default_value($val);
 }
@@ -247,7 +246,7 @@ sub iter_cidr {
       while (my $c = shift @cidr) {
         if (wantarray) {
           push(@items, [$c, $block->[1]]);
-          continue;
+          next;
         }
         else {
           return [$c, $block->[1]];
@@ -309,28 +308,43 @@ sub iter_keys {
   };
 }
 
-sub add {
-  my $self = shift;
+use Data::Dumper;
+
+sub _parse_entry {
+  my $class = shift;
   my($range, $lo, $hi, $label);
   if (@_ == 1) {
     if (@{$_[0]} == 2) {
       ($range, $label) = @{shift()};
-      ($lo, $hi) = @$range;
+      $range = $class->_parse_range($range);
+      eval { ($lo, $hi) = ($range->first, $range->last) };
+      if ($@) {
+        ($lo, $hi) = @$range;
+      }
     }
     else {
       ($lo, $hi, $label) = @{shift()};
     }
   }
   elsif (@_ == 2) {
-    ($lo, $hi) = @{shift()};
-    $label = shift;
+    ($range, $label) = @_;
+    $range = $class->_parse_range($range);
+    eval { ($lo, $hi) = ($range->first, $range->last) };
+    if ($@) {
+      ($lo, $hi) = @$range;
+    }
   }
   else {
     ($lo, $hi, $label) = @_;
   }
+  return($lo, $hi, $label);
+}
+
+sub add {
+  my $self = shift;
+  my($lo, $hi, $label) = $self->_parse_entry(@_);
   my $val = $self->_get_or_insert_label($label);
   $self->_add_range($lo, $hi, $val);
-
   my $attr = $Attr{$self} ||= [];
   my $labels = $attr->[LABELS_ADDED] ||= {};
   if (! exists $labels->{$label}) {
@@ -346,13 +360,13 @@ sub add_all {
   my $key_class;
   my $type = $self->_get_content_type;
   if ($type == SILK_PMAP_TYPE_IPV4) {
-    $key_class = "Net::Silk::IPv4Addr";
+    $key_class = SILK_IPV4ADDR_CLASS;
   }
   elsif ($type == SILK_PMAP_TYPE_IPV6) {
-    $key_class = "Net::Silk::IPv6Addr";
+    $key_class = SILK_IPV6ADDR_CLASS;
   }
   elsif ($type == SILK_PMAP_TYPE_PROTO_PORT) {
-    $key_class = "Net::Silk::ProtoPort";
+    $key_class = SILK_PROTOPORT_CLASS;
   }
   else {
     croak "unknown pmap content type: $type\n";
@@ -360,14 +374,7 @@ sub add_all {
   my $original_ranges = shift;
   my @ranges;
   for my $range (@$original_ranges) {
-    my($lo, $hi, $label);
-    if (@$range == 2) {
-      ($lo, $hi) = @{$range->[0]};
-      $label = $range->[1];
-    }
-    else {
-      ($lo, $hi, $label) = @$range;
-    }
+    my($lo, $hi, $label) = $self->_parse_entry($range);
     $lo = $key_class->new($lo);
     $hi = $key_class->new($hi);
     push(@ranges, [$lo, $hi, $label]);
@@ -375,7 +382,7 @@ sub add_all {
   for my $range (map  { $_->[1] }
                  sort { $b->[0] <=> $a->[0] } 
                  map  { [$_->[0]->distance($_->[1]), $_] } @ranges) {
-    $self->add_range($range);
+    $self->add($range);
   }
 }
 
@@ -459,12 +466,26 @@ use Carp;
 
 use base qw( Net::Silk::Pmap );
 
+use Net::Silk qw( :basic );
+
 sub new {
   my $class = shift;
   my $self = $class->SUPER::new(@_, type => $class->SILK_PMAP_TYPE_IPV4);
   bless $self, $class;
 }
 
+sub _parse_range {
+  my $class = shift;
+  my $range = shift;
+  if ($range =~ /\//) {
+    $range = SILK_CIDR_CLASS->new($range);
+  }
+  elsif ($range =~ /-/) {
+    $range = SILK_RANGE_CLASS->new($range);
+  }
+  return $range;
+}
+
 ###
 
 package Net::Silk::Pmap::IPv6;
@@ -473,7 +494,7 @@ use strict;
 use warnings;
 use Carp;
 
-use base qw( Net::Silk::Pmap );
+use base qw( Net::Silk::Pmap::IPv4 );
 
 sub new {
   my $class = shift;
@@ -500,6 +521,16 @@ sub new {
   bless $self, $class;
 }
 
+sub _parse_range {
+  my $class = shift;
+  my $range = shift;
+  my($lo, $hi);
+  if ($range =~ /-/) {
+    $range = SILK_RANGE_CLASS->new($range);
+  }
+  return $range;
+}
+
 sub get {
   my $self = shift;
   # hash iter returns [hi,lo] keys
@@ -630,11 +661,11 @@ low L<Net::Silk::IPAddr> or L<Net::Silk::ProtoPort> values.
 
 =item add($lo, $hi, $label)
 
-Add a label to a range, specified either as a string (IP range or cidr,
-or port/proto pair) or as the low and hi values. NOTE: Nested ranges
-are allowed as long as the larger range is added first. The
-C<add_ranges()> method will properly sort these for you. Overlapping
-ranges are not allowed.
+Add a label to a range, specified either as a L<Net::Silk::CIDR> or
+L<Net::Silk::Range> object, string (IP range or cidr, or port/proto
+pair) or as the low and hi values. NOTE: Nested ranges are allowed as
+long as the larger range is added first. The C<add_all()> method will
+properly sort these for you. Overlapping ranges are not allowed.
 
 =item add_all(\@ranges)
 
